# Generated by Django 3.2 on 2021-04-19 22:51

from django.db import migrations

import django_tiptap.fields


class Migration(migrations.Migration):

    dependencies = [
        ("demo_app", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="note",
            name="somethingMore",
            field=django_tiptap.fields.TipTapTextField(null=True),
        ),
    ]
