import { Extension } from 'https://cdn.skypack.dev/pin/@tiptap/core@v2.0.0-beta.29-ehyNSRjShPZE49ePTtXD/mode=imports,min/optimized/@tiptap/core.js'

export const MyCustomExtension = Extension.create({
  name: 'mycustomExtension',

  // Your code goes here.
})
