# Generated by Django 3.0.14 on 2021-06-30 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("demo_app", "0002_note_somethingmore"),
    ]

    operations = [
        migrations.AlterField(
            model_name="note",
            name="id",
            field=models.AutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
