#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['django_tiptap']

package_data = \
{'': ['*'],
 'django_tiptap': ['static/*',
                   'static/django_tiptap/*',
                   'static/django_tiptap/css/*',
                   'templates/*',
                   'templates/forms/*']}

install_requires = \
['Django >= 2.2']

extras_require = \
{'dev': ['black', 'isort', 'pre-commit'], 'test': ['pytest']}

setup(name='django_tiptap',
      version='0.0.18',
      description='TipTap Editor in Django 🚀',
      author='Jeet Mandaliya & Max Patzelt',
      author_email='django.tiptap@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )
